@@ -1,5 +1,5 @@
 from cosmoglobe.sky import model_from_chain
 from cosmoglobe.sky.model import SkyModel
-from cosmoglobe.h5.chain import Chain
+from cosmoglobe.h5.chain import Chain, copy_chain, combine_chain
 from cosmoglobe.hub import get_test_chain
 from cosmoglobe.plot import plot, gnom, trace
